Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(621)

Unified Diff: chrome/browser/in_process_webkit/dom_storage_context.h

Issue 5722003: Make DOMStorageDispatcherHost be a message filter (and rename it accordingly)... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: get rid of _DELAY_HANDLE macro Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/in_process_webkit/dom_storage_context.h
===================================================================
--- chrome/browser/in_process_webkit/dom_storage_context.h (revision 69012)
+++ chrome/browser/in_process_webkit/dom_storage_context.h (working copy)
@@ -14,15 +14,15 @@
#include "base/time.h"
class DOMStorageArea;
-class DOMStorageDispatcherHost;
+class DOMStorageMessageFilter;
class DOMStorageNamespace;
class WebKitContext;
// This is owned by WebKitContext and is all the dom storage information that's
-// shared by all the ResourceMessageFilter/DOMStorageDispatcherHosts that share
-// the same profile. The specifics of responsibilities are fairly well
-// documented here and in StorageNamespace and StorageArea. Everything is only
-// to be accessed on the WebKit thread unless noted otherwise.
+// shared by all the DOMStorageMessageFilters that share the same profile. The
+// specifics of responsibilities are fairly well documented here and in
+// StorageNamespace and StorageArea. Everything is only to be accessed on the
+// WebKit thread unless noted otherwise.
//
// NOTE: Virtual methods facilitate mocking functions for testing.
class DOMStorageContext {
@@ -54,12 +54,12 @@
// namespace if it hasn't been already.
DOMStorageNamespace* GetStorageNamespace(int64 id, bool allocation_allowed);
// Sometimes an event from one DOM storage dispatcher host requires
// communication to all of them.
- typedef std::set<DOMStorageDispatcherHost*> DispatcherHostSet;
- void RegisterDispatcherHost(DOMStorageDispatcherHost* dispatcher_host);
- void UnregisterDispatcherHost(DOMStorageDispatcherHost* dispatcher_host);
- const DispatcherHostSet* GetDispatcherHostSet() const;
+ typedef std::set<DOMStorageMessageFilter*> MessageFilterSet;
+ void RegisterMessageFilter(DOMStorageMessageFilter* message_filter);
+ void UnregisterMessageFilter(DOMStorageMessageFilter* MessageFilter);
+ const MessageFilterSet* GetMessageFilterSet() const;
// Tells storage namespaces to purge any memory they do not need.
virtual void PurgeMemory();
@@ -133,9 +133,9 @@
// make it point directly to the dom storage path.
FilePath data_path_;
// All the DOMStorageDispatcherHosts that are attached to us. ONLY USE ON THE
// IO THREAD!
- DispatcherHostSet dispatcher_host_set_;
+ MessageFilterSet message_filter_set_;
// Maps ids to StorageAreas. We do NOT own these objects. StorageNamespace
// (which does own them) will notify us when we should remove the entries.
@@ -54,12 +54,12 @@
// namespace if it hasn't been already.
DOMStorageNamespace* GetStorageNamespace(int64 id, bool allocation_allowed);
- // Sometimes an event from one DOM storage dispatcher host requires
+ // Sometimes an event from one DOM storage message filter requires
// communication to all of them.
@@ -133,9 +133,9 @@
// make it point directly to the dom storage path.
FilePath data_path_;
- // All the DOMStorageDispatcherHosts that are attached to us. ONLY USE ON THE
+ // All the DOMStorageMessageFilters that are attached to us. ONLY USE ON THE
// IO THREAD!

Powered by Google App Engine
This is Rietveld 408576698